@@ -55,7 +55,7 @@ class Gates(Hilbert):
         return operator
 
     def V(self, target):
-        M = (1j+1)/2*self.Matrix([[1, -1j], [-1j, 1]]) # sqrt(X) ou sqrt(NOT)
+        M = (1j+1)/2*self.Matrix([[1, -1j], [-1j, 1]])  # sqrt(X) ou sqrt(NOT)
         list = self.getOrdListSimpleGate(target, M)
         operator = self.kronProduct(list)
         return operator
@@ -67,7 +67,7 @@ class Gates(Hilbert):
         return operator
 
     def T(self, target):
-        M = self.Matrix([[1, 0], [0, (1+1j)/sqrt(2)]]) # sqrt(S)
+        M = self.Matrix([[1, 0], [0, (1+1j)/sqrt(2)]])  # sqrt(S)
         list = self.getOrdListSimpleGate(target, M)
         operator = self.kronProduct(list)
         return operator
@@ -78,8 +78,14 @@ class Gates(Hilbert):
         operator = self.kronProduct(list)
         return operator
 
-    def U(self, target, theta, phi, _lambda):
-        M = self.Matrix([[exp(-1j*(phi+_lambda)/2)*cos(theta/2), -exp(-1j*(phi-_lambda)/2)*sin(theta/2)],
+    def U(self, target, *argv):  # U or theta, phi and _lambda
+        if(len(argv)==1):
+            M = self.Matrix(argv[0][0])
+        else:
+            theta = argv[0]
+            phi = argv[1]
+            _lambda = argv[2]
+            M = self.Matrix([[exp(-1j*(phi+_lambda)/2)*cos(theta/2), -exp(-1j*(phi-_lambda)/2)*sin(theta/2)],
                         [exp(-1j*(phi-_lambda)/2)*sin(theta/2), exp(1j*(phi+_lambda))*cos(theta/2)]])
         list = self.getOrdListSimpleGate(target, M)
         operator = self.kronProduct(list)
@@ -145,9 +151,35 @@ class Gates(Hilbert):
         operator = self.kronProduct(list1) + self.kronProduct(list2)
         return operator
 
-    def CU(self, control, target, theta, phi, _lambda):
-        M = self.Matrix([[exp(-1j*(phi+_lambda)/2)*cos(theta/2), -exp(-1j*(phi-_lambda)/2)*sin(theta/2)],
-                        [exp(-1j*(phi-_lambda)/2)*sin(theta/2), exp(1j*(phi+_lambda))*cos(theta/2)]])
+    def CRX(self, control, target, theta):
+        M = self.Matrix([[cos(theta/2), -1j*sin(theta/2)],
+                    [-1j*sin(theta/2), cos(theta/2)]])
+        list1,list2 = self.getOrdListCtrlGate(control, target, M)
+        operator = self.kronProduct(list1) + self.kronProduct(list2)
+        return operator
+
+    def CRY(self, control, target, theta):
+        M = self.Matrix([[cos(theta/2), -sin(theta/2)],
+                    [sin(theta/2), cos(theta/2)]])
+        list1, list2 = self.getOrdListCtrlGate(control, target, M)
+        operator = self.kronProduct(list1) + self.kronProduct(list2)
+        return operator
+
+    def CRZ(self, control, target, phi):
+        M = self.Matrix([[exp(-1j * phi / 2), 0], [0, exp(1j * phi / 2)]])
+        list1, list2 = self.getOrdListCtrlGate(control, target, M)
+        operator = self.kronProduct(list1) + self.kronProduct(list2)
+        return operator
+
+    def CU(self, control, target, *argv):  # U or theta, phi and _lambda
+        if(len(argv)==1):
+            M = self.Matrix(argv[0][0])
+        else:
+            theta = argv[0]
+            phi = argv[1]
+            _lambda = argv[2]
+            M = self.Matrix([[exp(-1j*(phi+_lambda)/2)*cos(theta/2), -exp(-1j*(phi-_lambda)/2)*sin(theta/2)],
+                        [exp(1j*(phi-_lambda)/2)*sin(theta/2), exp(1j*(phi+_lambda))*cos(theta/2)]])
         list1,list2 = self.getOrdListCtrlGate(control, target, M)
         operator = self.kronProduct(list1) + self.kronProduct(list2)
         return operator
