@@ -66,9 +66,9 @@ class LogicQuBit(Qubits, Gates, Circuit):
         operator = super().H(target)
         self.setOperation(operator)
 
-    def U(self, target, theta, phi, _lambda):
-        self.addOp("U", self.qubitsToList([target, theta, phi, _lambda]))
-        operator = super().U(target, theta, phi, _lambda)
+    def U(self, target, *argv):
+        self.addOp("U", self.qubitsToList([target, argv]))
+        operator = super().U(target, argv)
         self.setOperation(operator)
 
     def U3(self, target, theta, phi, _lambda):
@@ -119,9 +119,24 @@ class LogicQuBit(Qubits, Gates, Circuit):
         operator = super().CZ(control, target)
         self.setOperation(operator)
 
-    def CU(self, control, target, theta, phi, _lambda):
-        self.addOp("CU", self.qubitsToList([control, target, theta, phi, _lambda]))
-        operator = super().CU(control, target, theta, phi, _lambda)
+    def CRX(self, control, target, theta):
+        self.addOp("CRX", self.qubitsToList([control, target, theta]))
+        operator = super().CRX(control, target, theta)
+        self.setOperation(operator)
+
+    def CRY(self, control, target, theta):
+        self.addOp("CRY", self.qubitsToList([control, target, theta]))
+        operator = super().CRY(control, target, theta)
+        self.setOperation(operator)
+
+    def CRZ(self, control, target, phi):
+        self.addOp("CRZ", self.qubitsToList([control, target, phi]))
+        operator = super().CRZ(control, target, phi)
+        self.setOperation(operator)
+
+    def CU(self, control, target, *argv):
+        self.addOp("CU", self.qubitsToList([control, target]))
+        operator = super().CU(control, target, argv)
         self.setOperation(operator)
 
     def CU3(self, control, target, theta, phi, _lambda):
