@@ -255,9 +255,9 @@ class Qubit(Qubits, Gates, Circuit):
         operator = super().H(self.__id)
         self.setOperation(operator)
 
-    def U(self, theta, phi, _lambda):
-        self.addOp("U", self.qubitsToList([self.__id, theta, phi, _lambda]))
-        operator = super().U(self.__id, theta, phi, _lambda)
+    def U(self, *argv):
+        self.addOp("U", self.qubitsToList([self.__id, argv]))
+        operator = super().U(self.__id, argv)
         self.setOperation(operator)
 
     def U3(self, theta, phi, _lambda):
@@ -308,9 +308,24 @@ class Qubit(Qubits, Gates, Circuit):
         operator = super().CZ(control, self.__id)
         self.setOperation(operator)
 
-    def CU(self, control, theta, phi, _lambda):
-        self.addOp("CU", self.qubitsToList([control, self.__id, theta, phi, _lambda]))
-        operator = super().CU(control, self.__id, theta, phi, _lambda)
+    def CRX(self, control, theta):
+        self.addOp("CRX", self.qubitsToList([control, self.__id, theta]))
+        operator = super().CRX(control, self.__id, theta)
+        self.setOperation(operator)
+
+    def CRY(self, control, theta):
+        self.addOp("CRY", self.qubitsToList([control, self.__id, theta]))
+        operator = super().CRY(control, self.__id, theta)
+        self.setOperation(operator)
+
+    def CRZ(self, control, phi):
+        self.addOp("CRZ", self.qubitsToList([control, self.__id, phi]))
+        operator = super().CRZ(control, self.__id, phi)
+        self.setOperation(operator)
+
+    def CU(self, control, *argv):
+        self.addOp("CU", self.qubitsToList([control, self.__id]))
+        operator = super().CU(control, self.__id, argv)
         self.setOperation(operator)
 
     def CU3(self, control, theta, phi, _lambda):
